MTfit.probability
====================


.. literalinclude:: ../../src/MTfit/probability/probability.py

There are also Cython functions:


.. literalinclude:: ../../src/MTfit/probability/cprobability.pyx
    :end-before: # Test functions
    :language: cython